@@ -2,6 +2,12 @@
 # 1) That insertion and deletion produce the correct results with random strings
 # 2) That search (hamming, levenshtein and anchored) produce the same results as the internal `dist_matrix` and `dist_pairwise` functions
 
+if(requireNamespace("seqtrie", quietly=TRUE) &&
+   requireNamespace("stringi", quietly=TRUE) &&
+   requireNamespace("stringdist", quietly=TRUE) &&
+   requireNamespace("dplyr", quietly=TRUE)
+) {
+
 library(seqtrie)
 library(stringdist)
 library(stringi)
@@ -294,3 +300,5 @@ for(. in 1:NITER) {
     })
   
 }
+
+}
